NLSL: xarry Struct Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Data Types List
- Data Types
- Data Fields

Public Attributes | List of all members
xarry Struct Reference
Collaboration diagram for xarry:
[legend]

## Public Attributes
float | x
struct xarry * | next

## Detailed Description

Definition at line 77 of file pltx.c.

## Member Data Documentation

struct xarry* xarry::next

Definition at line 80 of file pltx.c.

float xarry::x

Definition at line 79 of file pltx.c.

The documentation for this struct was generated from the following file:

- pltx.c